EigenvectorMode

Enum EigenvectorMode 

pub enum EigenvectorMode {
    Out,
    In,
    All,
}
How to consider edge directions for eigenvector_centrality_full and friends. Mirrors upstream’s IGRAPH_OUT / IGRAPH_IN / IGRAPH_ALL.

Variants



Out

Standard convention: centrality of v is proportional to the sum of centralities of vertices pointing to v (we walk incoming edges of v). Equivalent to ARPACK’s “left eigenvector of the adjacency matrix”.



In

Reverse convention: centrality of v is proportional to the sum of centralities of vertices v points to (we walk outgoing edges of v). Equivalent to ARPACK’s “right eigenvector”.



All

Treat the graph as undirected and use the symmetric eigenvector path. Mandatory for undirected input.