ReciprocityMode

Enum ReciprocityMode 

pub enum ReciprocityMode {
    Default,
    Ratio,
}
Reciprocity formula choice. Counterpart of upstream’s igraph_reciprocity_t (IGRAPH_RECIPROCITY_DEFAULT / IGRAPH_RECIPROCITY_RATIO).

  • ReciprocityMode::Defaultrec / total_edges. The fraction of directed edges that have a reverse counterpart.
  • ReciprocityMode::Ratiorec / (rec + nonrec). The fraction of connected ordered vertex pairs that are reciprocal. The two formulas agree on graphs with no parallel edges.

Variants



Default

rec / total_edges.



Ratio

rec / (rec + nonrec).