pub fn greedy_clique_cover(graph: &Graph) -> IgraphResult<Vec<Vec<u32>>>Expand description
Find a greedy clique cover.
Iterates through vertices and greedily adds each to the first existing clique it can extend, or starts a new clique.
Returns a partition of vertices into cliques.
Examples
use rust_igraph::{Graph, greedy_clique_cover, is_clique_cover};
let g = Graph::from_edges(
&[(0,1),(0,2),(1,2),(3,4)], false, Some(5)
).unwrap();
let cover = greedy_clique_cover(&g).unwrap();
assert!(is_clique_cover(&g, &cover).unwrap());