pub fn has_mutual(graph: &Graph, loops: bool) -> IgraphResult<bool>Expand description
Check whether a directed graph has any mutual (reciprocal) edges.
For undirected graphs, returns true if there is at least one edge (all edges are mutual by definition).
Self-loops are considered mutual if loops is true.
Examples
use rust_igraph::{Graph, has_mutual};
let mut g = Graph::new(3, true).unwrap();
g.add_edge(0, 1).unwrap();
g.add_edge(1, 2).unwrap();
assert!(!has_mutual(&g, false).unwrap());
g.add_edge(1, 0).unwrap();
assert!(has_mutual(&g, false).unwrap());