local_scan_0_them

Function local_scan_0_them 

pub fn local_scan_0_them(
    us: &Graph,
    them: &Graph,
    weights_them: Option<&[f64]>,
    mode: DegreeMode,
) -> IgraphResult<Vec<f64>>
Local scan-0 on two graphs: degree/strength from them restricted to edges that also exist in us.

Both graphs must have the same vertex count and directedness.

Examples

use rust_igraph::{Graph, local_scan_0_them, DegreeMode};

let mut us = Graph::with_vertices(3);
us.add_edge(0, 1).unwrap();
us.add_edge(0, 2).unwrap();
let mut them = Graph::with_vertices(3);
them.add_edge(0, 1).unwrap();
them.add_edge(1, 2).unwrap();
let res = local_scan_0_them(&us, &them, None, DegreeMode::All).unwrap();
assert!((res[0] - 1.0).abs() < 1e-12);
assert!((res[1] - 1.0).abs() < 1e-12);
assert!((res[2] - 0.0).abs() < 1e-12);