AllShortestPathsDijkstra

Struct AllShortestPathsDijkstra 

pub struct AllShortestPathsDijkstra {
    pub paths: Vec<Vec<Vec<VertexId>>>,
    pub edge_paths: Vec<Vec<Vec<u32>>>,
    pub nrgeo: Vec<u64>,
}
Fields

paths: Vec<Vec<Vec<VertexId>>>

All shortest paths grouped by target vertex. paths[v] is the list of all shortest paths from the source to vertex v. If v is unreachable, paths[v] is empty. Each path includes both endpoints.

edge_paths: Vec<Vec<Vec<u32>>>

Edge paths grouped by target vertex. edge_paths[v] is the list of edge sequences along each shortest path from source to v.

nrgeo: Vec<u64>

Number of shortest paths to each vertex.