BiconnectedComponents

Struct BiconnectedComponents 

pub struct BiconnectedComponents {
    pub count: u32,
    pub components: Vec<Vec<VertexId>>,
    pub tree_edges: Vec<Vec<u32>>,
    pub component_edges: Vec<Vec<u32>>,
    pub articulation_points: Vec<VertexId>,
}
Fields

count: u32

Total number of biconnected components.

components: Vec<Vec<VertexId>>

components[i] lists the vertex ids of the i-th component.

tree_edges: Vec<Vec<u32>>

tree_edges[i] lists the edge ids that form a spanning tree of the i-th component. Same length as components.

component_edges: Vec<Vec<u32>>

component_edges[i] lists every edge id whose endpoints both lie in the i-th component. Same length as components. Counterpart of upstream’s component_edges output (CC-012).

articulation_points: Vec<VertexId>

Articulation points of the graph (in DFS-discovery order).