pub struct ClosenessCutoffResult {
pub scores: Vec<Option<f64>>,
pub reachable_count: Vec<u32>,
pub all_reachable: bool,
}Expand description
Result of closeness_cutoff.
Fields
scores: Vec<Option<f64>>Per-vertex closeness score. None for vertices with no reachable
neighbours within the cutoff distance.
reachable_count: Vec<u32>Per-vertex count of vertices reachable within the cutoff (excluding self).
all_reachable: boolWhether all vertices are reachable from every source within the cutoff.