EdgelistPercolation

Struct EdgelistPercolation 

pub struct EdgelistPercolation {
    pub giant_size: Vec<u32>,
    pub vertex_count: Vec<u32>,
}
Outputs of edgelist_percolation. Same length as the input edge slice. giant_size[i] is the size of the largest component after edge i is added; vertex_count[i] is the number of distinct vertices touched by edges 0..=i.

Fields

giant_size: Vec<u32>

Size of the largest connected component after edge i is added.

vertex_count: Vec<u32>

Cumulative count of distinct vertices touched by any edge in 0..=i.