GomoryHuTree

Struct GomoryHuTree 

pub struct GomoryHuTree {
    pub tree: Graph,
    pub flows: Vec<f64>,
}
Output of gomory_hu_tree — a weighted undirected tree on the same vertex set as the input graph, plus one flow value per tree edge.

The flow vector is indexed by tree edge id in the order they were added (tree.edge_endpoints(eid) gives the corresponding endpoints). flows.len() == tree.ecount() == max(vcount - 1, 0).

Fields

tree: Graph

Undirected tree with the same vertex count as the input graph and exactly max(vcount - 1, 0) edges.

flows: Vec<f64>

Tree-edge weights, in the same order as the edges of tree. Each entry is the value of the s-t min cut between the two endpoints of that tree edge in the original graph (and, by the Gomory-Hu property, the minimum cut value between every pair separated by that edge in the tree).