pub struct LeidenResult {
pub membership: Vec<u32>,
pub quality: f64,
pub nb_clusters: u32,
pub n_iterations_run: u32,
pub qualities: Vec<f64>,
}Expand description
Result of a Leiden run.
Fields
membership: Vec<u32>Length-vcount vector of compacted community labels in 0..k.
quality: f64Final value of the chosen objective function on membership.
nb_clusters: u32Number of distinct communities (k).
n_iterations_run: u32Number of outer iterations actually executed.
qualities: Vec<f64>Quality value at the end of each outer iteration.