ReachabilityResult

Struct ReachabilityResult 

pub struct ReachabilityResult {
    pub membership: Vec<u32>,
    pub csize: Vec<u32>,
    pub num_components: u32,
    pub reach: Vec<Vec<u64>>,
}
Result of a reachability analysis.

Fields

membership: Vec<u32>

membership[v] — component id for vertex v.

csize: Vec<u32>

csize[c] — number of vertices in component c.

num_components: u32

Number of components.

reach: Vec<Vec<u64>>

reach[c] — bitvector of length vcount; bit v is set if vertex v is reachable from any vertex in component c.

Implementations

Source

impl ReachabilityResult

pub fn is_reachable(&self, source: VertexId, target: VertexId) -> bool

Returns true if vertex target is reachable from vertex source.

Examples
use rust_igraph::{Graph, reachability, ReachabilityMode};

let mut g = Graph::new(3, true).unwrap();
g.add_edge(0, 1).unwrap();
g.add_edge(1, 2).unwrap();
let r = reachability(&g, ReachabilityMode::Out).unwrap();
assert!(r.is_reachable(0, 2));
assert!(!r.is_reachable(2, 0));
pub fn count_from(&self, v: VertexId) -> u32

Count how many vertices are reachable from v (including v).

Examples
use rust_igraph::{Graph, reachability, ReachabilityMode};

let mut g = Graph::new(3, true).unwrap();
g.add_edge(0, 1).unwrap();
g.add_edge(1, 2).unwrap();
let r = reachability(&g, ReachabilityMode::Out).unwrap();
assert_eq!(r.count_from(0), 3); // reaches 0, 1, 2
assert_eq!(r.count_from(2), 1); // reaches only itself