StCuts

Struct StCuts 

pub struct StCuts {
    pub cuts: Vec<Vec<u32>>,
    pub partition1s: Vec<Vec<VertexId>>,
}
Result of all_st_cuts.

cuts[i] and partition1s[i] describe the same cut: partition1s[i] is the source-side vertex set X (always contains source, never target), and cuts[i] lists the ids of the edges leaving X (from ∈ X, to ∉ X). Vertices within each partition and edge ids within each cut are sorted ascending.

Fields

cuts: Vec<Vec<u32>>

Edge-id list of each cut, sorted ascending.

partition1s: Vec<Vec<VertexId>>

Source-side vertex set generating each cut, sorted ascending.