pub struct StronglyRegularParams {
pub n: u32,
pub k: u32,
pub lambda: u32,
pub mu: u32,
}Expand description
Result of strongly regular graph recognition.
Fields
n: u32Number of vertices.
k: u32Degree of each vertex.
lambda: u32Number of common neighbors for each pair of adjacent vertices.
mu: u32Number of common neighbors for each pair of non-adjacent vertices.