VoronoiTiebreaker

Enum VoronoiTiebreaker 

pub enum VoronoiTiebreaker {
    First,
    Last,
    Random,
}
Tie-breaking rule used when two or more generators reach a vertex at the same distance.

Mirrors igraph_voronoi_tiebreaker_t from references/igraph/include/igraph_paths.h.

Variants



First

Keep the earliest generator (in input order) that reached the vertex. Counterpart of IGRAPH_VORONOI_FIRST.



Last

Always overwrite with the latest generator. Counterpart of IGRAPH_VORONOI_LAST.



Random

Pick one of the equidistant generators uniformly at random. Counterpart of IGRAPH_VORONOI_RANDOM. Uses a seeded SplitMix64 so results are reproducible per seed value.

Note: as in the C reference, VoronoiTiebreaker::Random does not guarantee that the resulting partitions are connected subgraphs (a tie-breaker chain can leave a vertex behind in a disconnected island of its assigned partition).