pub struct SimplifyAndColorize {
pub graph: Graph,
pub vertex_color: Vec<u32>,
pub edge_color: Vec<u32>,
}Expand description
The colored simple graph produced by simplify_and_colorize.
vertex_color has one entry per vertex of the input (self-loop
multiplicities); edge_color has one entry per edge of graph (the
parallel-edge multiplicities, each >= 1).
Fields
graph: GraphThe simplified graph: no self-loops, no multi-edges. Same vertex count and directedness as the input.
vertex_color: Vec<u32>Self-loop multiplicity of each input vertex (vcount entries).
edge_color: Vec<u32>Multiplicity of each merged edge in SimplifyAndColorize::graph
(ecount entries, each >= 1).