pub type AstarHeuristic<'a> = dyn Fn(VertexId, VertexId) -> f64 + 'a;Expand description
A heuristic estimating the distance from a candidate vertex (first argument) to the target vertex (second argument). Must be admissible (never overestimate the true remaining distance) for the result to be a true shortest path.